@@ -1,10 +1,8 @@
-# 字典
-# 模块
-# 获取自增ID
+from ._mock import MockType
 from .base import Base
 
 
-class Dictionary(Base):
+class Dictionary(Base, metaclass=MockType):
     def __init__(self, baseurl='http://dictionary-prod:8000', transport=None):
         super().__init__(baseurl, transport)
 
