@@ -1,7 +1,8 @@
+from ._mock import MockType
 from .base import Base
 
 
-class OpLog(Base):
+class OpLog(Base, metaclass=MockType):
     def __init__(self, baseurl='http://oplogapi-prod:8000', transport=None):
         super().__init__(baseurl, transport)
 
