@@ -1,5 +1,5 @@
 from .base import Base
-
+from ._mock import MockType
 
 # class TargetSearch(BaseModel):
 #     keyword: str = ""
@@ -16,7 +16,7 @@ from .base import Base
 #     page_size: int = 100000
 
 
-class Target(Base):
+class Target(Base, metaclass=MockType):
     def __init__(self, baseurl='http://targetapi-prod:8000', transport=None):
         super().__init__(baseurl, transport)
 
